searchData={"items":[{"type":"module","title":"ExFix","doc":"Elixir implementation of FIX Session Protocol FIXT.1.1.\nCurrently only supports FIX session initiator (buy side).","ref":"ExFix.html"},{"type":"module","title":"Usage - ExFix","doc":"```\ndefmodule MySessionHandler do\n  @behaviour ExFix.SessionHandler\n  require Logger\n\n  alias ExFix.InMessage\n  alias ExFix.OutMessage\n  alias ExFix.Parser\n\n  @msg_new_order_single  \"D\"\n\n  @field_account         \"1\"\n  @field_cl_ord_id      \"11\"\n  @field_order_qty      \"38\"\n  @field_ord_type       \"40\"\n  @field_price          \"44\"\n  @field_side           \"54\"\n  @field_symbol         \"55\"\n  @field_transact_time  \"60\"\n\n  @value_side_buy        \"1\"\n  @value_ord_type_limit  \"2\"\n\n  def on_logon(session_name, _env) do\n    spawn fn() ->","ref":"ExFix.html#module-usage"},{"type":"module","title":"Buy 10 shares of SYM1 for $1.23 per share - ExFix","doc":"@msg_new_order_single\n      |> OutMessage.new()\n      |> OutMessage.set_field(@field_account, 1234)\n      |> OutMessage.set_field(@field_cl_ord_id, \"cod12345\")\n      |> OutMessage.set_field(@field_order_qty, 10)\n      |> OutMessage.set_field(@field_ord_type, @value_ord_type_limit)\n      |> OutMessage.set_field(@field_price, 1.23)\n      |> OutMessage.set_field(@field_side, @value_side_buy)\n      |> OutMessage.set_field(@field_symbol, \"SYM1\")\n      |> OutMessage.set_field(@field_transact_time, DateTime.utc_now())\n      |> ExFix.send_message!(session_name)\n    end\n  end\n\n  def on_app_message(_session_name, _msg_type, %InMessage{} = msg, _env) do\n    Logger.info \"App msg received: #{inspect Parser.parse2(msg)}\"\n  end\n\n  def on_session_message(_session_name, _msg_type, %InMessage{} = msg, _env) do\n    Logger.info \"Session msg received: #{inspect Parser.parse2(msg)}\"\n  end\n\n  def on_logout(_session_id, _env), do: :ok\nend\n\nExFix.start_session_initiator(\"simulator\", \"BUY\", \"SELL\", MySessionHandler,\n  hostname: \"localhost\", port: 9876, username: \"user1\", password: \"pwd1\",\n  transport_mod: :ssl)\n```","ref":"ExFix.html#module-buy-10-shares-of-sym1-for-1-23-per-share"},{"type":"function","title":"ExFix.send_message!/2","doc":"Send FIX message to a session","ref":"ExFix.html#send_message!/2"},{"type":"function","title":"ExFix.start_session_initiator/5","doc":"Starts FIX session initiator","ref":"ExFix.html#start_session_initiator/5"},{"type":"function","title":"ExFix.stop_session/2","doc":"Stop FIX session","ref":"ExFix.html#stop_session/2"},{"type":"module","title":"ExFix.DateUtil","doc":"FIX DateTime related functions","ref":"ExFix.DateUtil.html"},{"type":"function","title":"ExFix.DateUtil.parse_date/1","doc":"Parse FIX formatted UTC date string (YYYYMMDD-HH:MM:SS.mmm)","ref":"ExFix.DateUtil.html#parse_date/1"},{"type":"function","title":"ExFix.DateUtil.serialize_date/1","doc":"","ref":"ExFix.DateUtil.html#serialize_date/1"},{"type":"module","title":"ExFix.DefaultDictionary","doc":"Simple FIX Dictionary","ref":"ExFix.DefaultDictionary.html"},{"type":"function","title":"ExFix.DefaultDictionary.subject/1","doc":"Callback implementation for  ExFix.Dictionary.subject/1 .","ref":"ExFix.DefaultDictionary.html#subject/1"},{"type":"module","title":"ExFix.DefaultSessionRegistry","doc":"FIX Session registry - Tracks status of FIX sessions","ref":"ExFix.DefaultSessionRegistry.html"},{"type":"function","title":"ExFix.DefaultSessionRegistry.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExFix.DefaultSessionRegistry.html#child_spec/1"},{"type":"function","title":"ExFix.DefaultSessionRegistry.get_session_status/1","doc":"Callback implementation for  ExFix.SessionRegistry.get_session_status/1 .","ref":"ExFix.DefaultSessionRegistry.html#get_session_status/1"},{"type":"function","title":"ExFix.DefaultSessionRegistry.init/1","doc":"Callback implementation for  GenServer.init/1 .","ref":"ExFix.DefaultSessionRegistry.html#init/1"},{"type":"function","title":"ExFix.DefaultSessionRegistry.session_on_init/1","doc":"Callback implementation for  ExFix.SessionRegistry.session_on_init/1 .","ref":"ExFix.DefaultSessionRegistry.html#session_on_init/1"},{"type":"function","title":"ExFix.DefaultSessionRegistry.session_update_status/2","doc":"Callback implementation for  ExFix.SessionRegistry.session_update_status/2 .","ref":"ExFix.DefaultSessionRegistry.html#session_update_status/2"},{"type":"function","title":"ExFix.DefaultSessionRegistry.start_link/1","doc":"","ref":"ExFix.DefaultSessionRegistry.html#start_link/1"},{"type":"function","title":"ExFix.DefaultSessionRegistry.start_session/2","doc":"Callback implementation for  ExFix.SessionRegistry.start_session/2 .","ref":"ExFix.DefaultSessionRegistry.html#start_session/2"},{"type":"function","title":"ExFix.DefaultSessionRegistry.stop_session/1","doc":"Callback implementation for  ExFix.SessionRegistry.stop_session/1 .","ref":"ExFix.DefaultSessionRegistry.html#stop_session/1"},{"type":"behaviour","title":"ExFix.Dictionary","doc":"FIX dictionary behaviour","ref":"ExFix.Dictionary.html"},{"type":"callback","title":"ExFix.Dictionary.subject/1","doc":"","ref":"ExFix.Dictionary.html#c:subject/1"},{"type":"type","title":"ExFix.Dictionary.subject_field/0","doc":"","ref":"ExFix.Dictionary.html#t:subject_field/0"},{"type":"module","title":"ExFix.InMessage","doc":"Represents a received FIX message.","ref":"ExFix.InMessage.html"},{"type":"function","title":"ExFix.InMessage.get_field/2","doc":"","ref":"ExFix.InMessage.html#get_field/2"},{"type":"type","title":"ExFix.InMessage.t/0","doc":"","ref":"ExFix.InMessage.html#t:t/0"},{"type":"module","title":"ExFix.OutMessage","doc":"FIX message built on application layer","ref":"ExFix.OutMessage.html"},{"type":"function","title":"ExFix.OutMessage.new/1","doc":"","ref":"ExFix.OutMessage.html#new/1"},{"type":"function","title":"ExFix.OutMessage.set_field/3","doc":"","ref":"ExFix.OutMessage.html#set_field/3"},{"type":"function","title":"ExFix.OutMessage.set_fields/2","doc":"","ref":"ExFix.OutMessage.html#set_fields/2"},{"type":"type","title":"ExFix.OutMessage.t/0","doc":"","ref":"ExFix.OutMessage.html#t:t/0"},{"type":"module","title":"ExFix.Parser","doc":"FIX message parser","ref":"ExFix.Parser.html"},{"type":"function","title":"ExFix.Parser.parse1/4","doc":"Parse - stage1","ref":"ExFix.Parser.html#parse1/4"},{"type":"function","title":"ExFix.Parser.parse2/1","doc":"Parse rest of the message","ref":"ExFix.Parser.html#parse2/1"},{"type":"function","title":"ExFix.Parser.parse/4","doc":"Parse full message","ref":"ExFix.Parser.html#parse/4"},{"type":"module","title":"ExFix.Serializer","doc":"FIX message serialization","ref":"ExFix.Serializer.html"},{"type":"function","title":"ExFix.Serializer.bin_sum/2","doc":"","ref":"ExFix.Serializer.html#bin_sum/2"},{"type":"function","title":"ExFix.Serializer.serialize/3","doc":"Encode FIX message","ref":"ExFix.Serializer.html#serialize/3"},{"type":"module","title":"ExFix.Session","doc":"FIX session protocol implementation","ref":"ExFix.Session.html"},{"type":"type","title":"ExFix.Session.fix_field/0","doc":"","ref":"ExFix.Session.html#t:fix_field/0"},{"type":"function","title":"ExFix.Session.get_extra_bytes/1","doc":"Returns session's extra bytes to be processed with the next segment","ref":"ExFix.Session.html#get_extra_bytes/1"},{"type":"function","title":"ExFix.Session.get_in_lastseq/1","doc":"Returns session's last sequence number accepted","ref":"ExFix.Session.html#get_in_lastseq/1"},{"type":"function","title":"ExFix.Session.get_in_queue/1","doc":"Returns inbound message queue (messages received with high sequence number)","ref":"ExFix.Session.html#get_in_queue/1"},{"type":"function","title":"ExFix.Session.get_in_queue_length/1","doc":"Returns length of inbound message queue","ref":"ExFix.Session.html#get_in_queue_length/1"},{"type":"function","title":"ExFix.Session.get_last_test_req_id/1","doc":"Returns ID of last Test Request sent","ref":"ExFix.Session.html#get_last_test_req_id/1"},{"type":"function","title":"ExFix.Session.get_status/1","doc":"Returns session's current status (offline, online, connecting, disconnecting). `online` means \"logged on\".","ref":"ExFix.Session.html#get_status/1"},{"type":"function","title":"ExFix.Session.handle_incoming_data/2","doc":"Handle incoming binary data","ref":"ExFix.Session.html#handle_incoming_data/2"},{"type":"function","title":"ExFix.Session.handle_timeout/2","doc":"Respond to timeout (receiving or transmiting messages)","ref":"ExFix.Session.html#handle_timeout/2"},{"type":"function","title":"ExFix.Session.init/1","doc":"State initialization","ref":"ExFix.Session.html#init/1"},{"type":"function","title":"ExFix.Session.process_incoming_message/5","doc":"Process incoming message","ref":"ExFix.Session.html#process_incoming_message/5"},{"type":"function","title":"ExFix.Session.process_invalid_message/3","doc":"Process invalid message","ref":"ExFix.Session.html#process_invalid_message/3"},{"type":"function","title":"ExFix.Session.process_valid_message/4","doc":"Process valid message","ref":"ExFix.Session.html#process_valid_message/4"},{"type":"function","title":"ExFix.Session.send_message/2","doc":"Send application message","ref":"ExFix.Session.html#send_message/2"},{"type":"type","title":"ExFix.Session.session_in_queue/0","doc":"","ref":"ExFix.Session.html#t:session_in_queue/0"},{"type":"type","title":"ExFix.Session.session_name/0","doc":"","ref":"ExFix.Session.html#t:session_name/0"},{"type":"type","title":"ExFix.Session.session_result/0","doc":"","ref":"ExFix.Session.html#t:session_result/0"},{"type":"function","title":"ExFix.Session.session_start/1","doc":"Session start: send Logon msg","ref":"ExFix.Session.html#session_start/1"},{"type":"type","title":"ExFix.Session.session_status/0","doc":"","ref":"ExFix.Session.html#t:session_status/0"},{"type":"function","title":"ExFix.Session.session_stop/1","doc":"Session stop","ref":"ExFix.Session.html#session_stop/1"},{"type":"function","title":"ExFix.Session.set_out_queue/2","doc":"Utility function for tests: set out_queue to an arbitrary list of messages","ref":"ExFix.Session.html#set_out_queue/2"},{"type":"function","title":"ExFix.Session.set_time/2","doc":"Utility function for tests: simulates a certain point in time","ref":"ExFix.Session.html#set_time/2"},{"type":"type","title":"ExFix.Session.t/0","doc":"","ref":"ExFix.Session.html#t:t/0"},{"type":"module","title":"ExFix.Session.MessageToSend","doc":"Represents a FIX message sent to counterparty","ref":"ExFix.Session.MessageToSend.html"},{"type":"type","title":"ExFix.Session.MessageToSend.t/0","doc":"","ref":"ExFix.Session.MessageToSend.html#t:t/0"},{"type":"module","title":"ExFix.SessionConfig","doc":"FIX session configuration","ref":"ExFix.SessionConfig.html"},{"type":"type","title":"ExFix.SessionConfig.t/0","doc":"","ref":"ExFix.SessionConfig.html#t:t/0"},{"type":"behaviour","title":"ExFix.SessionHandler","doc":"FIX Session Handler behaviour. Declare callbacks to process received FIX messages\nand session events.","ref":"ExFix.SessionHandler.html"},{"type":"callback","title":"ExFix.SessionHandler.on_app_message/4","doc":"Callback - FIX message received (application level).\n\nThis function receives:\n- session id (String or PID), example: \"simulator\"\n- message type (String)\n  see [here](http://www.onixs.biz/fix-dictionary/5.0.SP2/msgs_by_msg_type.html)\n  for a complete list of FIX 5.0 SP2 message types.\n- msg - InMessage struct with message. If `msg.complete == false`, it is needed to call:\n  ```\n  msg = ExFix.Parser.parse2(msg)\n  ```\n- env - Map sent to `ExFix.start_session_initiator()`.","ref":"ExFix.SessionHandler.html#c:on_app_message/4"},{"type":"callback","title":"ExFix.SessionHandler.on_logon/2","doc":"Called after a Logon message is received from counterparty","ref":"ExFix.SessionHandler.html#c:on_logon/2"},{"type":"callback","title":"ExFix.SessionHandler.on_logout/2","doc":"Called after a Logout message is received from counterparty or after a\ndisconnection, which occurs first.","ref":"ExFix.SessionHandler.html#c:on_logout/2"},{"type":"callback","title":"ExFix.SessionHandler.on_session_message/4","doc":"FIX message received (session level). Same arguments of `on_message()`.","ref":"ExFix.SessionHandler.html#c:on_session_message/4"},{"type":"behaviour","title":"ExFix.SessionRegistry","doc":"Session registry.","ref":"ExFix.SessionRegistry.html"},{"type":"callback","title":"ExFix.SessionRegistry.get_session_status/1","doc":"Returns the current status of a FIX session","ref":"ExFix.SessionRegistry.html#c:get_session_status/1"},{"type":"callback","title":"ExFix.SessionRegistry.session_on_init/1","doc":"Invoked by FIX session, before connecting, to know if it's ok to connect","ref":"ExFix.SessionRegistry.html#c:session_on_init/1"},{"type":"callback","title":"ExFix.SessionRegistry.session_update_status/2","doc":"Invoked by FIX session to update its status.","ref":"ExFix.SessionRegistry.html#c:session_update_status/2"},{"type":"callback","title":"ExFix.SessionRegistry.start_session/2","doc":"Starts a FIX session","ref":"ExFix.SessionRegistry.html#c:start_session/2"},{"type":"callback","title":"ExFix.SessionRegistry.stop_session/1","doc":"Stops a FIX session","ref":"ExFix.SessionRegistry.html#c:stop_session/1"},{"type":"module","title":"ExFix.SessionTimer","doc":"Keeps track of sent and received messages. Triggers a message with the\nform `{:timeout, timer_name}` when no sent/received messages are registered\nfor a certain time.","ref":"ExFix.SessionTimer.html"},{"type":"function","title":"ExFix.SessionTimer.setup_timer/2","doc":"Sends a message `{:timeout, name}` when no messages are received for a certain time.","ref":"ExFix.SessionTimer.html#setup_timer/2"},{"type":"function","title":"ExFix.SessionTimer.timer_loop/3","doc":"Main loop of timer process","ref":"ExFix.SessionTimer.html#timer_loop/3"},{"type":"module","title":"ExFix.SessionWorker","doc":"FIX session worker","ref":"ExFix.SessionWorker.html"},{"type":"function","title":"ExFix.SessionWorker.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExFix.SessionWorker.html#child_spec/1"},{"type":"function","title":"ExFix.SessionWorker.send_message!/2","doc":"","ref":"ExFix.SessionWorker.html#send_message!/2"},{"type":"function","title":"ExFix.SessionWorker.start_link/1","doc":"","ref":"ExFix.SessionWorker.html#start_link/1"},{"type":"function","title":"ExFix.SessionWorker.start_link/2","doc":"","ref":"ExFix.SessionWorker.html#start_link/2"},{"type":"function","title":"ExFix.SessionWorker.stop/1","doc":"","ref":"ExFix.SessionWorker.html#stop/1"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}